aboutsummaryrefslogtreecommitdiffstats
path: root/tap-rpcprogs.c
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2006-05-31 17:38:42 +0000
committerGerald Combs <gerald@wireshark.org>2006-05-31 17:38:42 +0000
commit8958bab6dee184310e4393e33591eb0cef1f7de1 (patch)
treeafe5ad59d2280ee36c0ce913a4252cddc692436f /tap-rpcprogs.c
parent7bc853b62b59e6cf66ba2c3a2699a8a79ef864bd (diff)
Tethereal/tethereal -> TShark/tshark.
svn path=/trunk/; revision=18268
Diffstat (limited to 'tap-rpcprogs.c')
-rw-r--r--tap-rpcprogs.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tap-rpcprogs.c b/tap-rpcprogs.c
index 15517517fb..fcad0f54f9 100644
--- a/tap-rpcprogs.c
+++ b/tap-rpcprogs.c
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply SRT statistics to twireshark.
* It is only used by twireshark and not wireshark
*/
#ifdef HAVE_CONFIG_H
@@ -227,7 +227,7 @@ rpcprogs_init(const char *optarg _U_, void* userdata _U_)
error_string=register_tap_listener("rpc", NULL, NULL, NULL, rpcprogs_packet, rpcprogs_draw);
if(error_string){
- fprintf(stderr,"twireshark: Couldn't register rpc,programs tap: %s\n",
+ fprintf(stderr,"tshark: Couldn't register rpc,programs tap: %s\n",
error_string->str);
g_string_free(error_string, TRUE);
exit(1);
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply SRT statistics to twireshark.
- * It is only used by twireshark and not wireshark
+/* This module provides rpc call/reply SRT statistics to tshark.
+ * It is only used by tshark and not wireshark
*/
#ifdef HAVE_CONFIG_H